@@ -29,8 +29,10 @@ impl Command for ExprDatePart {
                 SyntaxShape::String,
                 "Part of the date to capture.  Possible values are year, quarter, month, week, weekday, day, hour, minute, second, millisecond, microsecond, nanosecond",
             )
-            .input_type(Type::Custom("expression".into()))
-            .output_type(Type::Custom("expression".into()))
+            .input_output_type(
+                Type::Custom("expression".into()),
+                Type::Custom("expression".into()),
+            )
             .category(Category::Custom("expression".into()))
     }
 
