@@ -25,8 +25,7 @@ impl Command for ExprOtherwise {
                 SyntaxShape::Any,
                 "expression to apply when no when predicate matches",
             )
-            .input_type(Type::Any)
-            .output_type(Type::Custom("expression".into()))
+            .input_output_type(Type::Any, Type::Custom("expression".into()))
             .category(Category::Custom("expression".into()))
     }
 
