@@ -17,14 +17,21 @@ impl Command for SubCommand {
     fn signature(&self) -> Signature {
         Signature::build("into decimal")
             .input_output_types(vec![
+                (Type::Int, Type::Number),
                 (Type::String, Type::Number),
                 (Type::Bool, Type::Number),
+                (Type::Table(vec![]), Type::Table(vec![])),
+                (
+                    Type::List(Box::new(Type::Any)),
+                    Type::List(Box::new(Type::Number)),
+                ),
             ])
             .rest(
                 "rest",
                 SyntaxShape::CellPath,
                 "for a data structure input, convert data at the given cell paths",
             )
+            .allow_variants_without_examples(true)
             .category(Category::Conversions)
     }
 
