@@ -19,7 +19,10 @@ impl Command for LoadEnv {
 
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("load-env")
-            .input_output_types(vec![(Type::Record(vec![]), Type::Nothing)])
+            .input_output_types(vec![
+                (Type::Record(vec![]), Type::Nothing),
+                (Type::Nothing, Type::Nothing),
+            ])
             .allow_variants_without_examples(true)
             .optional(
                 "update",
