@@ -1,6 +1,8 @@
 use std::path::PathBuf;
 
-use nu_engine::{eval_block_with_early_return, find_in_dirs_env, redirect_env, CallExt};
+use nu_engine::{
+    eval_block_with_early_return, find_in_dirs_env, get_dirs_var_from_call, redirect_env, CallExt,
+};
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
@@ -42,21 +44,30 @@ impl Command for SourceEnv {
 
         // Note: this hidden positional is the block_id that corresponded to the 0th position
         // it is put here by the parser
-        let block_id: i64 = call.req_parser_info(engine_state, caller_stack, 0)?;
+        let block_id: i64 = call.req_parser_info(engine_state, caller_stack, "block_id")?;
 
         // Set the currently evaluated directory (file-relative PWD)
-        let mut parent = if let Some(path) =
-            find_in_dirs_env(&source_filename.item, engine_state, caller_stack)?
-        {
+        let file_path = if let Some(path) = find_in_dirs_env(
+            &source_filename.item,
+            engine_state,
+            caller_stack,
+            get_dirs_var_from_call(call),
+        )? {
             PathBuf::from(&path)
         } else {
             return Err(ShellError::FileNotFound(source_filename.span));
         };
-        parent.pop();
 
-        let file_pwd = Value::string(parent.to_string_lossy(), call.head);
+        if let Some(parent) = file_path.parent() {
+            let file_pwd = Value::string(parent.to_string_lossy(), call.head);
 
-        caller_stack.add_env_var("FILE_PWD".to_string(), file_pwd);
+            caller_stack.add_env_var("FILE_PWD".to_string(), file_pwd);
+        }
+
+        caller_stack.add_env_var(
+            "CURRENT_FILE".to_string(),
+            Value::string(file_path.to_string_lossy(), call.head),
+        );
 
         // Evaluate the block
         let block = engine_state.get_block(block_id as usize).clone();
@@ -76,6 +87,7 @@ impl Command for SourceEnv {
 
         // Remove the file-relative PWD
         caller_stack.remove_env_var(engine_state, "FILE_PWD");
+        caller_stack.remove_env_var(engine_state, "CURRENT_FILE");
 
         result
     }
