@@ -16,11 +16,16 @@ impl Command for Append {
 
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("append")
-            .input_output_types(vec![(
-                Type::List(Box::new(Type::Any)),
-                Type::List(Box::new(Type::Any)),
-            )])
+            .input_output_types(vec![
+                (
+                    Type::List(Box::new(Type::Any)),
+                    Type::List(Box::new(Type::Any)),
+                ),
+                (Type::Record(vec![]), Type::Table(vec![])),
+                (Type::String, Type::String),
+            ])
             .required("row", SyntaxShape::Any, "the row, list, or table to append")
+            .allow_variants_without_examples(true)
             .category(Category::Filters)
     }
 
