@@ -98,7 +98,7 @@ impl Command for Items {
             PipelineData::Empty => Ok(PipelineData::Empty),
             PipelineData::Value(Value::Record { cols, vals, .. }, ..) => Ok(cols
                 .into_iter()
-                .zip(vals.into_iter())
+                .zip(vals)
                 .map_while(run_for_each_item)
                 .into_pipeline_data(ctrlc)),
             // Errors
