@@ -6,7 +6,6 @@ mod compact;
 mod default;
 mod drop;
 mod each;
-mod each_while;
 mod empty;
 mod enumerate;
 mod every;
@@ -33,8 +32,6 @@ mod reduce;
 mod reject;
 mod rename;
 mod reverse;
-mod roll;
-mod rotate;
 mod select;
 mod shuffle;
 mod skip;
@@ -46,7 +43,6 @@ mod transpose;
 mod uniq;
 mod uniq_by;
 mod update;
-mod update_cells;
 mod upsert;
 mod utils;
 mod values;
@@ -63,7 +59,6 @@ pub use compact::Compact;
 pub use default::Default;
 pub use drop::*;
 pub use each::Each;
-pub use each_while::EachWhile;
 pub use empty::Empty;
 pub use enumerate::Enumerate;
 pub use every::Every;
@@ -90,8 +85,6 @@ pub use reduce::Reduce;
 pub use reject::Reject;
 pub use rename::Rename;
 pub use reverse::Reverse;
-pub use roll::*;
-pub use rotate::Rotate;
 pub use select::Select;
 pub use shuffle::Shuffle;
 pub use skip::*;
@@ -103,7 +96,6 @@ pub use transpose::Transpose;
 pub use uniq::*;
 pub use uniq_by::UniqBy;
 pub use update::Update;
-pub use update_cells::UpdateCells;
 pub use upsert::Upsert;
 pub use values::Values;
 pub use where_::Where;
