@@ -1,7 +1,6 @@
 mod command;
 mod csv;
 mod delimited;
-mod html;
 mod json;
 mod md;
 mod nuon;
@@ -14,7 +13,6 @@ mod yaml;
 pub use self::csv::ToCsv;
 pub use self::toml::ToToml;
 pub use command::To;
-pub use html::ToHtml;
 pub use json::ToJson;
 pub use md::ToMd;
 pub use nuon::value_to_string;
