@@ -12,8 +12,15 @@ impl Command for SubCommand {
 
     fn signature(&self) -> Signature {
         Signature::build("math floor")
-            .input_output_types(vec![(Type::Number, Type::Int)])
+            .input_output_types(vec![
+                (Type::Number, Type::Int),
+                (
+                    Type::List(Box::new(Type::Number)),
+                    Type::List(Box::new(Type::Number)),
+                ),
+            ])
             .vectorizes_over_list(true)
+            .allow_variants_without_examples(true)
             .category(Category::Math)
     }
 
