@@ -12,15 +12,10 @@ use nu_protocol::{
 use super::PathSubcommandArguments;
 
 struct Arguments {
-    columns: Option<Vec<String>>,
     extension: Option<Spanned<String>>,
 }
 
-impl PathSubcommandArguments for Arguments {
-    fn get_columns(&self) -> Option<Vec<String>> {
-        self.columns.clone()
-    }
-}
+impl PathSubcommandArguments for Arguments {}
 
 #[derive(Clone)]
 pub struct SubCommand;
@@ -32,13 +27,10 @@ impl Command for SubCommand {
 
     fn signature(&self) -> Signature {
         Signature::build("path parse")
-            .input_output_types(vec![(Type::String, Type::Record(vec![]))])
-            .named(
-                "columns",
-                SyntaxShape::Table,
-                "For a record or table input, convert strings at the given columns",
-                Some('c'),
-            )
+            .input_output_types(vec![
+                (Type::String, Type::Record(vec![])),
+                (Type::List(Box::new(Type::String)), Type::Table(vec![])),
+            ])
             .named(
                 "extension",
                 SyntaxShape::String,
@@ -65,7 +57,6 @@ On Windows, an extra 'prefix' column is added."#
     ) -> Result<PipelineData, ShellError> {
         let head = call.head;
         let args = Arguments {
-            columns: call.get_flag(engine_state, stack, "columns")?,
             extension: call.get_flag(engine_state, stack, "extension")?,
         };
 
@@ -126,9 +117,40 @@ On Windows, an extra 'prefix' column is added."#
                 }),
             },
             Example {
-                description: "Parse all paths under the 'name' column",
-                example: r"ls | path parse -c [ name ]",
-                result: None,
+                description: "Parse all paths in a list",
+                example: r"[ C:\Users\viking.d C:\Users\spam.txt ] | path parse",
+                result: Some(Value::test_list(vec![
+                    Value::Record {
+                        cols: vec![
+                            "prefix".into(),
+                            "parent".into(),
+                            "stem".into(),
+                            "extension".into(),
+                        ],
+                        vals: vec![
+                            Value::test_string("C:"),
+                            Value::test_string(r"C:\Users"),
+                            Value::test_string("viking"),
+                            Value::test_string("d"),
+                        ],
+                        span: Span::test_data(),
+                    },
+                    Value::Record {
+                        cols: vec![
+                            "prefix".into(),
+                            "parent".into(),
+                            "stem".into(),
+                            "extension".into(),
+                        ],
+                        vals: vec![
+                            Value::test_string("C:"),
+                            Value::test_string(r"C:\Users"),
+                            Value::test_string("spam"),
+                            Value::test_string("txt"),
+                        ],
+                        span: Span::test_data(),
+                    },
+                ])),
             },
         ]
     }
@@ -168,9 +190,28 @@ On Windows, an extra 'prefix' column is added."#
                 }),
             },
             Example {
-                description: "Parse all paths under the 'name' column",
-                example: r"ls | path parse -c [ name ]",
-                result: None,
+                description: "Parse all paths in a list",
+                example: r"[ /home/viking.d /home/spam.txt ] | path parse",
+                result: Some(Value::test_list(vec![
+                    Value::Record {
+                        cols: vec!["parent".into(), "stem".into(), "extension".into()],
+                        vals: vec![
+                            Value::test_string("/home"),
+                            Value::test_string("viking"),
+                            Value::test_string("d"),
+                        ],
+                        span: Span::test_data(),
+                    },
+                    Value::Record {
+                        cols: vec!["parent".into(), "stem".into(), "extension".into()],
+                        vals: vec![
+                            Value::test_string("/home"),
+                            Value::test_string("spam"),
+                            Value::test_string("txt"),
+                        ],
+                        span: Span::test_data(),
+                    },
+                ])),
             },
         ]
     }
