@@ -179,7 +179,7 @@ impl Command for Du {
                     }
                 }
                 Err(e) => {
-                    output.push(Value::Error { error: e });
+                    output.push(Value::Error { error: Box::new(e) });
                 }
             }
         }
