@@ -7,12 +7,13 @@ mod kill;
 mod sleep;
 mod term_size;
 
-pub use ansi::{Ansi, AnsiGradient, AnsiLink, AnsiStrip};
+pub use ansi::{Ansi, AnsiStrip};
 pub use clear::Clear;
 pub use dir_info::{DirBuilder, DirInfo, FileInfo};
 pub use du::Du;
 pub use input::Input;
 pub use input::InputList;
+pub use input::InputListen;
 pub use kill::Kill;
 pub use sleep::Sleep;
 pub use term_size::TermSize;
