@@ -18,8 +18,18 @@ impl Command for DecodeBase64 {
             .input_output_types(vec![
                 (Type::String, Type::String),
                 (Type::String, Type::Binary),
+                (
+                    Type::List(Box::new(Type::String)),
+                    Type::List(Box::new(Type::String)),
+                ),
+                (
+                    Type::List(Box::new(Type::String)),
+                    Type::List(Box::new(Type::Binary)),
+                ),
+                (Type::Table(vec![]), Type::Table(vec![])),
             ])
             .vectorizes_over_list(true)
+            .allow_variants_without_examples(true)
             .named(
                 "character-set",
                 SyntaxShape::String,
