@@ -1,7 +1,6 @@
 mod char_;
 mod detect_columns;
 mod encode_decode;
-mod format;
 mod parse;
 mod size;
 mod split;
@@ -10,7 +9,6 @@ mod str_;
 pub use char_::Char;
 pub use detect_columns::*;
 pub use encode_decode::*;
-pub use format::*;
 pub use parse::*;
 pub use size::Size;
 pub use split::*;
