@@ -38,7 +38,7 @@ impl Command for SubCommand {
     }
 
     fn search_terms(&self) -> Vec<&str> {
-        vec!["separate", "divide"]
+        vec!["separate", "divide", "regex"]
     }
 
     fn run(
