@@ -28,7 +28,12 @@ impl Command for SubCommand {
 
     fn signature(&self) -> Signature {
         Signature::build("str ends-with")
-            .input_output_types(vec![(Type::String, Type::Bool)])
+            .input_output_types(vec![
+                (Type::String, Type::Bool),
+                (Type::List(Box::new(Type::String)), Type::List(Box::new(Type::Bool))),
+                (Type::Table(vec![]), Type::Table(vec![])),
+            ])
+            .allow_variants_without_examples(true)
             .vectorizes_over_list(true)
             .required("string", SyntaxShape::String, "the string to match")
             .rest(
@@ -73,9 +78,12 @@ impl Command for SubCommand {
                 result: Some(Value::test_bool(true)),
             },
             Example {
-                description: "Checks if string ends with '.txt'",
-                example: "'my_library.rb' | str ends-with '.txt'",
-                result: Some(Value::test_bool(false)),
+                description: "Checks if strings end with '.txt'",
+                example: "['my_library.rb', 'README.txt'] | str ends-with '.txt'",
+                result: Some(Value::test_list(vec![
+                    Value::test_bool(false),
+                    Value::test_bool(true),
+                ])),
             },
             Example {
                 description: "Checks if string ends with '.RB', case-insensitive",
@@ -94,7 +102,7 @@ fn action(input: &Value, args: &Arguments, head: Span) -> Value {
             } else {
                 s.ends_with(&args.substring)
             };
-            Value::boolean(ends_with, head)
+            Value::bool(ends_with, head)
         }
         Value::Error { .. } => input.clone(),
         _ => Value::Error {
