@@ -29,7 +29,12 @@ impl Command for SubCommand {
 
     fn signature(&self) -> Signature {
         Signature::build("str length")
-            .input_output_types(vec![(Type::String, Type::Int)])
+            .input_output_types(vec![
+                (Type::String, Type::Int),
+                (Type::List(Box::new(Type::String)), Type::List(Box::new(Type::Int))),
+                (Type::Table(vec![]), Type::Table(vec![])),
+            ])
+            .allow_variants_without_examples(true)
             .vectorizes_over_list(true)
             .switch(
                 "grapheme-clusters",
