@@ -30,8 +30,13 @@ impl Command for SubCommand {
 
     fn signature(&self) -> Signature {
         Signature::build("str starts-with")
-            .input_output_types(vec![(Type::String, Type::Bool)])
+            .input_output_types(vec![
+                (Type::String, Type::Bool),
+                (Type::List(Box::new(Type::String)), Type::List(Box::new(Type::Bool))),
+                (Type::Table(vec![]), Type::Table(vec![])),
+            ])
             .vectorizes_over_list(true)
+            .allow_variants_without_examples(true)
             .required("string", SyntaxShape::String, "the string to match")
             .rest(
                 "rest",
@@ -110,7 +115,7 @@ fn action(
             } else {
                 s.starts_with(substring)
             };
-            Value::boolean(starts_with, head)
+            Value::bool(starts_with, head)
         }
         Value::Error { .. } => input.clone(),
         _ => Value::Error {
