@@ -114,7 +114,7 @@ prints out the list properly."#
                 // dbg!("value::record");
                 let mut items = vec![];
 
-                for (i, (c, v)) in cols.into_iter().zip(vals.into_iter()).enumerate() {
+                for (i, (c, v)) in cols.into_iter().zip(vals).enumerate() {
                     items.push((i, c, v.into_string(", ", config)))
                 }
 
