@@ -1,22 +1,16 @@
-use nu_test_support::{nu, pipeline};
+use nu_test_support::nu;
 
 #[test]
 fn append_assign_int() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
             mut a = [1 2];
             $a ++= [3 4];
             $a
-        "#
-    ));
+        "#);
 
-    let expected = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let expected = nu!(r#"
             [1 2 3 4]
-        "#
-    ));
+        "#);
 
     print!("{}", actual.out);
     print!("{}", expected.out);
@@ -25,21 +19,15 @@ fn append_assign_int() {
 
 #[test]
 fn append_assign_string() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
             mut a = [a b];
             $a ++= [c d];
             $a
-        "#
-    ));
+        "#);
 
-    let expected = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let expected = nu!(r#"
             [a b c d]
-        "#
-    ));
+        "#);
 
     print!("{}", actual.out);
     print!("{}", expected.out);
@@ -48,21 +36,15 @@ fn append_assign_string() {
 
 #[test]
 fn append_assign_any() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
             mut a = [1 2 a];
             $a ++= [b 3];
             $a
-        "#
-    ));
+        "#);
 
-    let expected = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let expected = nu!(r#"
             [1 2 a b 3]
-        "#
-    ));
+        "#);
 
     print!("{}", actual.out);
     print!("{}", expected.out);
@@ -71,21 +53,15 @@ fn append_assign_any() {
 
 #[test]
 fn append_assign_both_empty() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
             mut a = [];
             $a ++= [];
             $a
-        "#
-    ));
+        "#);
 
-    let expected = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let expected = nu!(r#"
             []
-        "#
-    ));
+        "#);
 
     print!("{}", actual.out);
     print!("{}", expected.out);
@@ -94,14 +70,11 @@ fn append_assign_both_empty() {
 
 #[test]
 fn append_assign_type_mismatch() {
-    let actual = nu!(
-        cwd: ".", pipeline(
-        r#"
+    let actual = nu!(r#"
             mut a = [1 2];
             $a ++= [a];
             $a | to json -r;
-        "#
-    ));
+        "#);
 
     assert_eq!(actual.out, r#"[1,2,"a"]"#);
 }
