@@ -2,9 +2,7 @@ use nu_test_support::nu;
 
 #[test]
 fn loop_doesnt_auto_print_in_each_iteration() {
-    let actual = nu!(
-        cwd: ".",
-        r#"
+    let actual = nu!("
         mut total = 0;
         loop {
             if $total == 3 {
@@ -13,8 +11,7 @@ fn loop_doesnt_auto_print_in_each_iteration() {
                 $total += 1;
             }
             echo 1
-        }"#
-    );
+        }");
     // Make sure we don't see any of these values in the output
     // As we do not auto-print loops anymore
     assert!(!actual.out.contains('1'));
@@ -22,9 +19,7 @@ fn loop_doesnt_auto_print_in_each_iteration() {
 
 #[test]
 fn loop_break_on_external_failed() {
-    let actual = nu!(
-        cwd: ".",
-        r#"
+    let actual = nu!("
         mut total = 0;
         loop {
             if $total == 3 {
@@ -34,8 +29,7 @@ fn loop_break_on_external_failed() {
             }
             print 1;
             nu --testbin fail;
-        }"#
-    );
+        }");
     // Note: nu! macro auto replace "\n" and "\r\n" with ""
     // so our output will be `1`.
     assert_eq!(actual.out, "1");
@@ -43,9 +37,7 @@ fn loop_break_on_external_failed() {
 
 #[test]
 fn failed_loop_should_break_running() {
-    let actual = nu!(
-        cwd: ".",
-        r#"
+    let actual = nu!("
         mut total = 0;
         loop {
             if $total == 3 {
@@ -55,7 +47,6 @@ fn failed_loop_should_break_running() {
             }
             nu --testbin fail;
         }
-        print 3"#
-    );
+        print 3");
     assert!(!actual.out.contains('3'));
 }
