@@ -45,10 +45,7 @@ fn moves_columns_before() {
                 -------,-------,   D   ,---,--------,   R    ,---------
                 -------,-------,   E   ,---,--------,   S    ,---------
                 -------,-------,   :   ,---,--------,   :    ,---------
-                -------,-------,   J   ,---,--------,   O    ,---------
-                -------,-------,   N   ,---,--------,   A    ,---------
-                -------,-------,   T   ,---,--------,   H    ,---------
-                -------,-------,   A   ,---,--------,   N    ,---------
+                -------,-------,   J   ,---,--------,   T    ,---------
             "#,
         )]);
 
@@ -65,7 +62,7 @@ fn moves_columns_before() {
             "#
         ));
 
-        assert!(actual.out.contains("ANDRES::JONATHAN"));
+        assert!(actual.out.contains("ANDRES::JT"));
     })
 }
 
@@ -80,10 +77,7 @@ fn moves_a_column_after() {
                 -------,-------,   D   ,---,--------,   R    ,---------
                 -------,-------,   E   ,---,--------,   S    ,---------
                 -------,-------,   :   ,---,--------,   :    ,---------
-                -------,-------,   J   ,---,--------,   O    ,---------
-                -------,-------,   N   ,---,--------,   A    ,---------
-                -------,-------,   T   ,---,--------,   H    ,---------
-                -------,-------,   A   ,---,--------,   N    ,---------
+                -------,-------,   J   ,---,--------,   T    ,---------
             "#,
         )]);
 
@@ -101,7 +95,7 @@ fn moves_a_column_after() {
             "#
         ));
 
-        assert!(actual.out.contains("ANDRES::JONATHAN"));
+        assert!(actual.out.contains("ANDRES::JT"));
     })
 }
 
@@ -116,10 +110,7 @@ fn moves_columns_after() {
                 -------,-------,   D   ,---,--------,   R    ,---------
                 -------,-------,   E   ,---,--------,   S    ,---------
                 -------,-------,   :   ,---,--------,   :    ,---------
-                -------,-------,   J   ,---,--------,   O    ,---------
-                -------,-------,   N   ,---,--------,   A    ,---------
-                -------,-------,   T   ,---,--------,   H    ,---------
-                -------,-------,   A   ,---,--------,   N    ,---------
+                -------,-------,   J   ,---,--------,   T    ,---------
             "#,
         )]);
 
