@@ -104,7 +104,7 @@ fn separate_redirection() {
                 sandbox.with_files(vec![FileWithContent("test.sh", script_body)]);
                 nu!(
                     cwd: dirs.test(),
-                    r#"bash test.sh out> out.txt err> err.txt"#
+                    "bash test.sh out> out.txt err> err.txt"
                 );
             }
             #[cfg(windows)]
@@ -112,7 +112,7 @@ fn separate_redirection() {
                 sandbox.with_files(vec![FileWithContent("test.bat", script_body)]);
                 nu!(
                     cwd: dirs.test(),
-                    r#"cmd /D /c test.bat out> out.txt err> err.txt"#
+                    "cmd /D /c test.bat out> out.txt err> err.txt"
                 );
             }
             // check for stdout redirection file.
@@ -142,10 +142,10 @@ fn same_target_redirection_with_too_much_stderr_not_hang_nushell() {
 
         nu!(
             cwd: dirs.test(), pipeline(
-                r#"
-                let-env LARGE = (open --raw a_large_file.txt);
+                "
+                $env.LARGE = (open --raw a_large_file.txt);
                 nu --testbin echo_env_stderr LARGE out+err> another_large_file.txt
-                "#
+                "
             ),
         );
 
@@ -166,7 +166,7 @@ fn redirection_keep_exit_codes() {
                 sandbox.with_files(vec![FileWithContent("test.sh", script_body)]);
                 nu!(
                     cwd: dirs.test(),
-                    r#"bash test.sh out> out.txt err> err.txt; echo $env.LAST_EXIT_CODE"#
+                    "bash test.sh out> out.txt err> err.txt; echo $env.LAST_EXIT_CODE"
                 )
             };
             #[cfg(windows)]
@@ -174,7 +174,7 @@ fn redirection_keep_exit_codes() {
                 sandbox.with_files(vec![FileWithContent("test.bat", script_body)]);
                 nu!(
                     cwd: dirs.test(),
-                    r#"cmd /D /c test.bat out> out.txt err> err.txt; echo $env.LAST_EXIT_CODE"#
+                    "cmd /D /c test.bat out> out.txt err> err.txt; echo $env.LAST_EXIT_CODE"
                 )
             };
             assert_eq!(output.out, "10")
@@ -196,7 +196,7 @@ fn redirection_with_pipeline_works() {
 
             nu!(
                 cwd: dirs.test(),
-                r#"bash test.sh out> out.txt | describe"#
+                "bash test.sh out> out.txt | describe"
             );
             // check for stdout redirection file.
             let expected_out_file = dirs.test().join("out.txt");
@@ -205,3 +205,62 @@ fn redirection_with_pipeline_works() {
         },
     )
 }
+
+#[test]
+fn redirect_support_variable() {
+    Playground::setup("redirect_out_support_variable", |dirs, _sandbox| {
+        let output = nu!(
+            cwd: dirs.test(),
+            "let x = 'tmp_file'; echo 'hello' out> $x; open tmp_file"
+        );
+
+        assert!(output.out.contains("hello"));
+
+        let output = nu!(
+            cwd: dirs.test(),
+            "let x = 'tmp_file'; echo 'hello' out+err> $x; open tmp_file"
+        );
+
+        assert!(output.out.contains("hello"));
+    })
+}
+
+#[test]
+fn separate_redirection_support_variable() {
+    Playground::setup(
+        "external with both stdout and stderr messages, to different file",
+        |dirs, sandbox| {
+            let script_body = r#"
+        echo message
+        echo message 1>&2
+        "#;
+            let expect_body = "message";
+
+            #[cfg(not(windows))]
+            {
+                sandbox.with_files(vec![FileWithContent("test.sh", script_body)]);
+                nu!(
+                    cwd: dirs.test(),
+                    r#"let o_f = "out.txt"; let e_f = "err.txt"; bash test.sh out> $o_f err> $e_f"#
+                );
+            }
+            #[cfg(windows)]
+            {
+                sandbox.with_files(vec![FileWithContent("test.bat", script_body)]);
+                nu!(
+                    cwd: dirs.test(),
+                    r#"let o_f = "out.txt"; let e_f = "err.txt"; cmd /D /c test.bat out> $o_f err> $e_f"#
+                );
+            }
+            // check for stdout redirection file.
+            let expected_out_file = dirs.test().join("out.txt");
+            let actual = file_contents(expected_out_file);
+            assert!(actual.contains(expect_body));
+
+            // check for stderr redirection file.
+            let expected_err_file = dirs.test().join("err.txt");
+            let actual = file_contents(expected_err_file);
+            assert!(actual.contains(expect_body));
+        },
+    )
+}
