@@ -53,7 +53,7 @@ fn condition_is_met() {
 
 #[test]
 fn fail_on_non_iterator() {
-    let actual = nu!(cwd: ".", pipeline("1 | take until {|row| $row == 2}"));
+    let actual = nu!("1 | take until {|row| $row == 2}");
 
-    assert!(actual.err.contains("only_supports_this_input_type"));
+    assert!(actual.err.contains("command doesn't support"));
 }
