@@ -113,47 +113,61 @@ pub struct Config {
 impl Default for Config {
     fn default() -> Config {
         Config {
-            filesize_metric: false,
-            table_mode: "rounded".into(),
-            table_show_empty: true,
-            external_completer: None,
+            show_banner: true,
+
             use_ls_colors: true,
-            color_config: HashMap::new(),
-            use_grid_icons: false,
-            footer_mode: FooterMode::RowCount(25),
-            float_precision: 4,
-            max_external_completion_results: 100,
-            filesize_format: "auto".into(),
-            use_ansi_coloring: true,
-            quick_completions: true,
-            partial_completions: true,
-            completion_algorithm: "prefix".into(),
-            edit_mode: "emacs".into(),
-            max_history_size: i64::MAX,
+            show_clickable_links_in_ls: true,
+
+            rm_always_trash: false,
+
+            cd_with_abbreviations: false,
+
+            table_mode: "rounded".into(),
+            table_index_mode: TableIndexMode::Always,
+            table_show_empty: true,
+            trim_strategy: TRIM_STRATEGY_DEFAULT,
+
+            datetime_normal_format: None,
+            datetime_table_format: None,
+
+            explore: HashMap::new(),
+
+            max_history_size: 100_000,
             sync_history_on_enter: true,
             history_file_format: HistoryFileFormat::PlainText,
             history_isolation: false,
-            keybindings: Vec::new(),
-            menus: Vec::new(),
-            hooks: Hooks::new(),
-            rm_always_trash: false,
-            shell_integration: false,
-            buffer_editor: String::new(),
-            table_index_mode: TableIndexMode::Always,
-            cd_with_abbreviations: false,
+
             case_sensitive_completions: false,
+            quick_completions: true,
+            partial_completions: true,
+            completion_algorithm: "prefix".into(),
             enable_external_completion: true,
-            trim_strategy: TRIM_STRATEGY_DEFAULT,
-            show_banner: true,
-            bracketed_paste: true,
-            show_clickable_links_in_ls: true,
-            render_right_prompt_on_last_line: false,
-            explore: HashMap::new(),
+            max_external_completion_results: 100,
+            external_completer: None,
+
+            filesize_metric: false,
+            filesize_format: "auto".into(),
+
+            cursor_shape_emacs: NuCursorShape::Line,
             cursor_shape_vi_insert: NuCursorShape::Block,
             cursor_shape_vi_normal: NuCursorShape::UnderScore,
-            cursor_shape_emacs: NuCursorShape::Line,
-            datetime_normal_format: None,
-            datetime_table_format: None,
+
+            color_config: HashMap::new(),
+            use_grid_icons: true,
+            footer_mode: FooterMode::RowCount(25),
+            float_precision: 2,
+            buffer_editor: String::new(),
+            use_ansi_coloring: true,
+            bracketed_paste: true,
+            edit_mode: "emacs".into(),
+            shell_integration: false,
+            render_right_prompt_on_last_line: false,
+
+            hooks: Hooks::new(),
+
+            menus: Vec::new(),
+
+            keybindings: Vec::new(),
         }
     }
 }
@@ -255,13 +269,13 @@ impl Value {
                 } else {
                     invalid!(Some(*$span), "should be a bool");
                     // Reconstruct
-                    $vals[$index] = Value::boolean(config.$setting, *$span);
+                    $vals[$index] = Value::bool(config.$setting, *$span);
                 }
             };
         }
         macro_rules! try_int {
             ($cols:ident, $vals:ident, $index:ident, $span:expr, $setting:ident) => {
-                if let Ok(b) = &$vals[$index].as_integer() {
+                if let Ok(b) = &$vals[$index].as_int() {
                     config.$setting = *b;
                 } else {
                     invalid!(Some(*$span), "should be an int");
@@ -336,8 +350,8 @@ impl Value {
                             vals[index] = Value::record(
                                 vec!["use_ls_colors".into(), "clickable_links".into()],
                                 vec![
-                                    Value::boolean(config.use_ls_colors, *span),
-                                    Value::boolean(config.show_clickable_links_in_ls, *span),
+                                    Value::bool(config.use_ls_colors, *span),
+                                    Value::bool(config.show_clickable_links_in_ls, *span),
                                 ],
                                 *span,
                             );
@@ -369,8 +383,8 @@ impl Value {
                             vals[index] = Value::record(
                                 vec!["use_ls_colors".into(), "clickable_links".into()],
                                 vec![
-                                    Value::boolean(config.use_ls_colors, *span),
-                                    Value::boolean(config.show_clickable_links_in_ls, *span),
+                                    Value::bool(config.use_ls_colors, *span),
+                                    Value::bool(config.show_clickable_links_in_ls, *span),
                                 ],
                                 *span,
                             );
@@ -401,7 +415,7 @@ impl Value {
                             // Reconstruct
                             vals[index] = Value::record(
                                 vec!["always_trash".into()],
-                                vec![Value::boolean(config.rm_always_trash, *span)],
+                                vec![Value::bool(config.rm_always_trash, *span)],
                                 *span,
                             );
                         }
@@ -481,10 +495,10 @@ impl Value {
                                     "isolation".into(),
                                 ],
                                 vec![
-                                    Value::boolean(config.sync_history_on_enter, *span),
+                                    Value::bool(config.sync_history_on_enter, *span),
                                     Value::int(config.max_history_size, *span),
                                     reconstruct_history_file_format!(span),
-                                    Value::boolean(config.history_isolation, *span),
+                                    Value::bool(config.history_isolation, *span),
                                 ],
                                 *span,
                             );
@@ -510,7 +524,7 @@ impl Value {
                                     vec![
                                         Value::int(config.max_external_completion_results, *$span),
                                         reconstruct_external_completer!($span),
-                                        Value::boolean(config.enable_external_completion, *$span),
+                                        Value::bool(config.enable_external_completion, *$span),
                                     ],
                                     *$span,
                                 )
@@ -648,10 +662,10 @@ impl Value {
                                     "external".into(),
                                 ],
                                 vec![
-                                    Value::boolean(config.quick_completions, *span),
-                                    Value::boolean(config.partial_completions, *span),
+                                    Value::bool(config.quick_completions, *span),
+                                    Value::bool(config.partial_completions, *span),
                                     Value::string(config.completion_algorithm.clone(), *span),
-                                    Value::boolean(config.case_sensitive_completions, *span),
+                                    Value::bool(config.case_sensitive_completions, *span),
                                     reconstruct_external!(span),
                                 ],
                                 *span,
@@ -870,7 +884,7 @@ impl Value {
                                         ],
                                         vec![
                                             Value::string("wrapping", *$span),
-                                            Value::boolean(*try_to_keep_words, *$span),
+                                            Value::bool(*try_to_keep_words, *$span),
                                         ],
                                         *$span,
                                     ),
@@ -968,7 +982,7 @@ impl Value {
                                     Value::string(config.table_mode.clone(), *span),
                                     reconstruct_index_mode!(span),
                                     reconstruct_trim_strategy!(span),
-                                    Value::boolean(config.table_show_empty, *span),
+                                    Value::bool(config.table_show_empty, *span),
                                 ],
                                 *span,
                             )
@@ -1012,7 +1026,7 @@ impl Value {
                             vals[index] = Value::record(
                                 vec!["metric".into(), "format".into()],
                                 vec![
-                                    Value::boolean(config.filesize_metric, *span),
+                                    Value::bool(config.filesize_metric, *span),
                                     Value::string(config.filesize_format.clone(), *span),
                                 ],
                                 *span,
@@ -1256,7 +1270,7 @@ impl Value {
                             vals[index] = Value::record(
                                 vec!["metric".into(), "format".into()],
                                 vec![
-                                    Value::boolean(config.filesize_metric, *span),
+                                    Value::bool(config.filesize_metric, *span),
                                     Value::string(config.filesize_format.clone(), *span),
                                 ],
                                 *span,
