@@ -114,8 +114,6 @@ pub struct Signature {
     pub rest_positional: Option<PositionalArg>,
     pub vectorizes_over_list: bool,
     pub named: Vec<Flag>,
-    pub input_type: Type,
-    pub output_type: Type,
     pub input_output_types: Vec<(Type, Type)>,
     pub allow_variants_without_examples: bool,
     pub is_filter: bool,
@@ -215,8 +213,6 @@ impl Signature {
             optional_positional: vec![],
             rest_positional: None,
             vectorizes_over_list: false,
-            input_type: Type::Any,
-            output_type: Type::Any,
             input_output_types: vec![],
             allow_variants_without_examples: false,
             named: vec![],
@@ -227,6 +223,46 @@ impl Signature {
         }
     }
 
+    // Gets the input type from the signature
+    pub fn get_input_type(&self) -> Type {
+        match self.input_output_types.len() {
+            0 => Type::Any,
+            1 => self.input_output_types[0].0.clone(),
+            _ => {
+                let first = &self.input_output_types[0].0;
+                if self
+                    .input_output_types
+                    .iter()
+                    .all(|(input, _)| input == first)
+                {
+                    first.clone()
+                } else {
+                    Type::Any
+                }
+            }
+        }
+    }
+
+    // Gets the output type from the signature
+    pub fn get_output_type(&self) -> Type {
+        match self.input_output_types.len() {
+            0 => Type::Any,
+            1 => self.input_output_types[0].1.clone(),
+            _ => {
+                let first = &self.input_output_types[0].1;
+                if self
+                    .input_output_types
+                    .iter()
+                    .all(|(_, output)| output == first)
+                {
+                    first.clone()
+                } else {
+                    Type::Any
+                }
+            }
+        }
+    }
+
     // Add a default help option to a signature
     pub fn add_help(mut self) -> Signature {
         // default help flag
@@ -423,14 +459,8 @@ impl Signature {
     }
 
     /// Changes the input type of the command signature
-    pub fn input_type(mut self, input_type: Type) -> Signature {
-        self.input_type = input_type;
-        self
-    }
-
-    /// Changes the output type of the command signature
-    pub fn output_type(mut self, output_type: Type) -> Signature {
-        self.output_type = output_type;
+    pub fn input_output_type(mut self, input_type: Type, output_type: Type) -> Signature {
+        self.input_output_types.push((input_type, output_type));
         self
     }
 
