@@ -1006,6 +1006,11 @@ impl ProcessInfo {
         self.pid
     }
 
+    /// Parent PID of process
+    pub fn ppid(&self) -> i32 {
+        self.ppid
+    }
+
     /// Name of command
     pub fn name(&self) -> String {
         self.command.clone()
