@@ -1,6 +1,6 @@
 use nu_test_support::fs::Stub::FileWithContentToBeTrimmed;
 use nu_test_support::playground::Playground;
-use nu_test_support::{nu, nu_repl_code, pipeline};
+use nu_test_support::{nu, nu_repl_code};
 use pretty_assertions::assert_eq;
 
 #[test]
@@ -9,11 +9,11 @@ fn module_private_import_decl() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     use spam.nu foo-helper
 
                     export def foo [] { foo-helper }
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -23,9 +23,9 @@ fn module_private_import_decl() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu foo"#, r#"foo"#];
+        let inp = &["use main.nu foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -37,11 +37,11 @@ fn module_private_import_alias() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     use spam.nu foo-helper
 
                     export def foo [] { foo-helper }
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -50,9 +50,9 @@ fn module_private_import_alias() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu foo"#, r#"foo"#];
+        let inp = &["use main.nu foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -64,9 +64,9 @@ fn module_private_import_decl_not_public() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     use spam.nu foo-helper
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -76,9 +76,9 @@ fn module_private_import_decl_not_public() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu foo"#, r#"foo-helper"#];
+        let inp = &["use main.nu foo", "foo-helper"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert!(!actual.err.is_empty());
     })
@@ -90,9 +90,9 @@ fn module_public_import_decl() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export use spam.nu foo
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -102,9 +102,9 @@ fn module_public_import_decl() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu foo"#, r#"foo"#];
+        let inp = &["use main.nu foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -116,9 +116,9 @@ fn module_public_import_alias() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export use spam.nu foo
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -127,9 +127,9 @@ fn module_public_import_alias() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu foo"#, r#"foo"#];
+        let inp = &["use main.nu foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -141,21 +141,21 @@ fn module_nested_imports() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export use spam.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
-                r#"
+                "
                     export use spam2.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam2.nu",
-                r#"
+                "
                     export use spam3.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam3.nu",
@@ -165,13 +165,13 @@ fn module_nested_imports() {
                 "#,
             )]);
 
-        let inp1 = &[r#"use main.nu foo"#, r#"foo"#];
-        let inp2 = &[r#"use main.nu bar"#, r#"bar"#];
+        let inp1 = &["use main.nu foo", "foo"];
+        let inp2 = &["use main.nu bar", "bar"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp1.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp1.join("; "));
         assert_eq!(actual.out, "foo");
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp2.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp2.join("; "));
         assert_eq!(actual.out, "bar");
     })
 }
@@ -185,21 +185,21 @@ fn module_nested_imports_in_dirs() {
             .mkdir("spam/spam3")
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export use spam/spam.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam.nu",
-                r#"
+                "
                     export use spam2/spam2.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam2/spam2.nu",
-                r#"
+                "
                     export use ../spam3/spam3.nu [ foo bar ]
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam3/spam3.nu",
@@ -209,13 +209,13 @@ fn module_nested_imports_in_dirs() {
                 "#,
             )]);
 
-        let inp1 = &[r#"use main.nu foo"#, r#"foo"#];
-        let inp2 = &[r#"use main.nu bar"#, r#"bar"#];
+        let inp1 = &["use main.nu foo", "foo"];
+        let inp2 = &["use main.nu bar", "bar"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp1.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp1.join("; "));
         assert_eq!(actual.out, "foo");
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp2.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp2.join("; "));
         assert_eq!(actual.out, "bar");
     })
 }
@@ -226,9 +226,9 @@ fn module_public_import_decl_prefixed() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export use spam.nu
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
@@ -238,9 +238,9 @@ fn module_public_import_decl_prefixed() {
                 "#,
             )]);
 
-        let inp = &[r#"use main.nu"#, r#"main spam foo"#];
+        let inp = &["use main.nu", "main spam foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -261,16 +261,16 @@ fn module_nested_imports_in_dirs_prefixed() {
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam.nu",
-                r#"
+                "
                     export use spam2/spam2.nu
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam2/spam2.nu",
-                r#"
+                "
                     export use ../spam3/spam3.nu
                     export use ../spam3/spam3.nu foo
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam/spam3/spam3.nu",
@@ -280,13 +280,13 @@ fn module_nested_imports_in_dirs_prefixed() {
                 "#,
             )]);
 
-        let inp1 = &[r#"use main.nu"#, r#"main spam2 foo"#];
-        let inp2 = &[r#"use main.nu "spam2 spam3 bar""#, r#"spam2 spam3 bar"#];
+        let inp1 = &["use main.nu", "main spam2 foo"];
+        let inp2 = &[r#"use main.nu "spam2 spam3 bar""#, "spam2 spam3 bar"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp1.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp1.join("; "));
         assert_eq!(actual.out, "foo");
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp2.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp2.join("; "));
         assert_eq!(actual.out, "bar");
     })
 }
@@ -297,22 +297,22 @@ fn module_import_env_1() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export-env { source-env spam.nu }
 
                     export def foo [] { $env.FOO_HELPER }
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
                 r#"
-                    export-env { let-env FOO_HELPER = "foo" }
+                    export-env { $env.FOO_HELPER = "foo" }
                 "#,
             )]);
 
-        let inp = &[r#"source-env main.nu"#, r#"use main.nu foo"#, r#"foo"#];
+        let inp = &["source-env main.nu", "use main.nu foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -324,20 +324,20 @@ fn module_import_env_2() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "main.nu",
-                r#"
+                "
                     export-env { source-env spam.nu }
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
                 r#"
-                    export-env { let-env FOO = "foo" }
+                    export-env { $env.FOO = "foo" }
                 "#,
             )]);
 
-        let inp = &[r#"source-env main.nu"#, r#"$env.FOO"#];
+        let inp = &["source-env main.nu", "$env.FOO"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -348,14 +348,14 @@ fn module_cyclical_imports_0() {
     Playground::setup("module_cyclical_imports_0", |dirs, sandbox| {
         sandbox.with_files(vec![FileWithContentToBeTrimmed(
             "spam.nu",
-            r#"
+            "
                     use eggs.nu
-                "#,
+                ",
         )]);
 
-        let inp = &[r#"module eggs { use spam.nu }"#];
+        let inp = &["module eggs { use spam.nu }"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert!(actual.err.contains("module not found"));
     })
@@ -366,14 +366,14 @@ fn module_cyclical_imports_1() {
     Playground::setup("module_cyclical_imports_1", |dirs, sandbox| {
         sandbox.with_files(vec![FileWithContentToBeTrimmed(
             "spam.nu",
-            r#"
+            "
                     use spam.nu
-                "#,
+                ",
         )]);
 
-        let inp = &[r#"use spam.nu"#];
+        let inp = &["use spam.nu"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert!(actual.err.contains("cyclical"));
     })
@@ -385,20 +385,20 @@ fn module_cyclical_imports_2() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
-                r#"
+                "
                     use eggs.nu
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "eggs.nu",
-                r#"
+                "
                     use spam.nu
-                "#,
+                ",
             )]);
 
-        let inp = &[r#"use spam.nu"#];
+        let inp = &["use spam.nu"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert!(actual.err.contains("cyclical"));
     })
@@ -410,26 +410,26 @@ fn module_cyclical_imports_3() {
         sandbox
             .with_files(vec![FileWithContentToBeTrimmed(
                 "spam.nu",
-                r#"
+                "
                     use eggs.nu
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "eggs.nu",
-                r#"
+                "
                     use bacon.nu
-                "#,
+                ",
             )])
             .with_files(vec![FileWithContentToBeTrimmed(
                 "bacon.nu",
-                r#"
+                "
                     use spam.nu
-                "#,
+                ",
             )]);
 
-        let inp = &[r#"use spam.nu"#];
+        let inp = &["use spam.nu"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert!(actual.err.contains("cyclical"));
     })
@@ -445,9 +445,9 @@ fn module_import_const_file() {
             "#,
         )]);
 
-        let inp = &[r#"const file = 'spam.nu'"#, r#"use $file foo"#, r#"foo"#];
+        let inp = &["const file = 'spam.nu'", "use $file foo", "foo"];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -465,12 +465,12 @@ fn module_import_const_module_name() {
 
         let inp = &[
             r#"module spam { export def foo [] { "foo" } }"#,
-            r#"const mod = 'spam'"#,
-            r#"use $mod foo"#,
-            r#"foo"#,
+            "const mod = 'spam'",
+            "use $mod foo",
+            "foo",
         ];
 
-        let actual = nu!(cwd: dirs.test(), pipeline(&inp.join("; ")));
+        let actual = nu!(cwd: dirs.test(), &inp.join("; "));
 
         assert_eq!(actual.out, "foo");
     })
@@ -480,7 +480,7 @@ fn module_import_const_module_name() {
 fn module_valid_def_name() {
     let inp = &[r#"module spam { def spam [] { "spam" } }"#];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert_eq!(actual.out, "");
 }
@@ -489,7 +489,7 @@ fn module_valid_def_name() {
 fn module_invalid_def_name() {
     let inp = &[r#"module spam { export def spam [] { "spam" } }"#];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert!(actual.err.contains("named_as_module"));
 }
@@ -498,7 +498,7 @@ fn module_invalid_def_name() {
 fn module_valid_alias_name_1() {
     let inp = &[r#"module spam { alias spam = echo "spam" }"#];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert_eq!(actual.out, "");
 }
@@ -507,7 +507,7 @@ fn module_valid_alias_name_1() {
 fn module_valid_alias_name_2() {
     let inp = &[r#"module spam { alias main = echo "spam" }"#];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert_eq!(actual.out, "");
 }
@@ -516,34 +516,34 @@ fn module_valid_alias_name_2() {
 fn module_invalid_alias_name() {
     let inp = &[r#"module spam { export alias spam = echo "spam" }"#];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert!(actual.err.contains("named_as_module"));
 }
 
 #[test]
 fn module_main_alias_not_allowed() {
-    let inp = &[r#"module spam { export alias main = echo 'spam' }"#];
+    let inp = &["module spam { export alias main = echo 'spam' }"];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert!(actual.err.contains("export_main_alias_not_allowed"));
 }
 
 #[test]
 fn module_valid_known_external_name() {
-    let inp = &[r#"module spam { extern spam [] }"#];
+    let inp = &["module spam { extern spam [] }"];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert_eq!(actual.out, "");
 }
 
 #[test]
 fn module_invalid_known_external_name() {
-    let inp = &[r#"module spam { export extern spam [] }"#];
+    let inp = &["module spam { export extern spam [] }"];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert!(actual.err.contains("named_as_module"));
 }
@@ -551,40 +551,40 @@ fn module_invalid_known_external_name() {
 #[test]
 fn main_inside_module_is_main() {
     let inp = &[
-        r#"module spam {
+        "module spam {
             export def main [] { 'foo' };
             export def foo [] { main }
-        }"#,
+        }",
         "use spam foo",
         "foo",
     ];
 
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
 
     assert_eq!(actual.out, "foo");
 }
 
 #[test]
 fn module_as_file() {
-    let inp = &[r#"module samples/spam.nu"#, "use spam foo", "foo"];
+    let inp = &["module samples/spam.nu", "use spam foo", "foo"];
 
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
 
     assert_eq!(actual.out, "foo");
 }
 
 #[test]
 fn export_module_as_file() {
-    let inp = &[r#"export module samples/spam.nu"#, "use spam foo", "foo"];
+    let inp = &["export module samples/spam.nu", "use spam foo", "foo"];
 
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
 
     assert_eq!(actual.out, "foo");
 }
 
 #[test]
 fn deep_import_patterns() {
-    let module_decl = r#"
+    let module_decl = "
         module spam {
             export module eggs {
                 export module beans {
@@ -593,22 +593,22 @@ fn deep_import_patterns() {
                 };
             };
         }
-    "#;
+    ";
 
     let inp = &[module_decl, "use spam", "spam eggs beans foo"];
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert_eq!(actual.out, "foo");
 
     let inp = &[module_decl, "use spam eggs", "eggs beans foo"];
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert_eq!(actual.out, "foo");
 
     let inp = &[module_decl, "use spam eggs beans", "beans foo"];
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert_eq!(actual.out, "foo");
 
     let inp = &[module_decl, "use spam eggs beans foo", "foo"];
-    let actual = nu!(cwd: ".", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert_eq!(actual.out, "foo");
 }
 
@@ -617,27 +617,27 @@ fn module_dir() {
     let import = "use samples/spam";
 
     let inp = &[import, "spam"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "spam");
 
     let inp = &[import, "spam foo"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "foo");
 
     let inp = &[import, "spam bar"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "bar");
 
     let inp = &[import, "spam foo baz"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "foobaz");
 
     let inp = &[import, "spam bar baz"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "barbaz");
 
     let inp = &[import, "spam baz"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual.out, "spambaz");
 }
 
@@ -646,19 +646,19 @@ fn module_dir_deep() {
     let import = "use samples/spam";
 
     let inp = &[import, "spam bacon"];
-    let actual_repl = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual_repl = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual_repl.out, "bacon");
 
     let inp = &[import, "spam bacon foo"];
-    let actual_repl = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual_repl = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual_repl.out, "bacon foo");
 
     let inp = &[import, "spam bacon beans"];
-    let actual_repl = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual_repl = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual_repl.out, "beans");
 
     let inp = &[import, "spam bacon beans foo"];
-    let actual_repl = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual_repl = nu!(cwd: "tests/modules", &inp.join("; "));
     assert_eq!(actual_repl.out, "beans foo");
 }
 
@@ -673,28 +673,28 @@ fn module_dir_import_twice_no_panic() {
 #[test]
 fn not_allowed_submodule_file() {
     let inp = &["use samples/not_allowed"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert!(actual.err.contains("invalid_module_file_name"));
 }
 
 #[test]
 fn module_dir_missing_mod_nu() {
     let inp = &["use samples/missing_mod_nu"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(cwd: "tests/modules", &inp.join("; "));
     assert!(actual.err.contains("module_missing_mod_nu_file"));
 }
 
 #[test]
 fn allowed_local_module() {
     let inp = &["module spam { module spam {} }"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.is_empty());
 }
 
 #[test]
 fn not_allowed_submodule() {
     let inp = &["module spam { export module spam {} }"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("named_as_module"));
 }
 
@@ -705,48 +705,48 @@ fn module_self_name() {
         "use spam",
         "spam",
     ];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert_eq!(actual.out, "spam");
 }
 
 #[test]
 fn module_self_name_main_not_allowed() {
     let inp = &[
-        r#"module spam {
+        "module spam {
             export def main [] { 'main spam' };
 
             export module mod {
                 export def main [] { 'mod spam' }
             }
-        }"#,
+        }",
         "use spam",
         "spam",
     ];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("module_double_main"));
 
     let inp = &[
-        r#"module spam {
+        "module spam {
             export module mod {
                 export def main [] { 'mod spam' }
             };
 
             export def main [] { 'main spam' }
-        }"#,
+        }",
         "use spam",
         "spam",
     ];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("module_double_main"));
 }
 
 #[test]
 fn module_main_not_found() {
     let inp = &["module spam {}", "use spam main"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("export_not_found"));
 
     let inp = &["module spam {}", "use spam [ main ]"];
-    let actual = nu!(cwd: "tests/modules", pipeline(&inp.join("; ")));
+    let actual = nu!(&inp.join("; "));
     assert!(actual.err.contains("export_not_found"));
 }
